@@ -246,7 +246,6 @@ EarlyOut:
 static int MimeInlineTextPlainFlowed_parse_line(const char* aLine,
                                                 int32_t length,
                                                 MimeObject* obj) {
-  int status;
   bool quoting =
       (obj->options &&
        (obj->options->format_out == nsMimeOutput::nsMimeMessageQuoting ||
@@ -378,7 +377,6 @@ static int MimeInlineTextPlainFlowed_parse_line(const char* aLine,
     }
   } else {
     CopyUTF8toUTF16(nsDependentCString(line, length), lineResult);
-    status = 0;
   }
 
   nsAutoCString preface;
@@ -448,7 +446,7 @@ static int MimeInlineTextPlainFlowed_parse_line(const char* aLine,
   }  // End Fixed line
 
   if (!(exdata->isSig && quoting && tObj->mStripSig)) {
-    status = MimeObject_write(obj, preface.get(), preface.Length(), true);
+    int status = MimeObject_write(obj, preface.get(), preface.Length(), true);
     if (status < 0) return status;
     nsAutoCString outString;
     if (obj->options->format_out != nsMimeOutput::nsMimeMessageSaveAs ||
@@ -557,15 +555,18 @@ static void Convert_whitespace(const char16_t a_current_char,
     number_of_space = 0;
   }
 
-  while (number_of_nbsp--) {
-    a_out_string.AppendLiteral("&nbsp;");
+  if (number_of_nbsp != 0) {
+    while (number_of_nbsp--) {
+      a_out_string.AppendLiteral("&nbsp;");
+    }
   }
 
-  while (number_of_space--) {
-    // a_out_string += ' '; gives error
-    a_out_string.Append(' ');
+  if (number_of_space != 0) {
+    while (number_of_space--) {
+      // a_out_string += ' '; gives error
+      a_out_string.Append(' ');
+    }
   }
-
   return;
 }
 
